# ts4uc
Tree Search for the UC Problem

This repo documents the research conducted for my PhD in RL for the Unit Commitment problem.

In particular, this gives the code I used to solve the UC problem with a variety of tree search methods, aided by RL agents trained in a simulated environment of the power system. The simulation environment can be found separately in the RL4UC package. 

### Tests

To run tests: 

```
cd tests
pytest
```
